<?php

namespace Contabilidade\Logic\ContasReferenciais;

use \Setforms2\Shared\Registry;
use \Contabilidade\Entities\Contrefe;
use \Geral\Util\DateUtil;

/**
 * Class Balancete
 * @package Contabilidade\Logic\Balancete\Balancete
 */
class ContasReferenciais
{

    public static function incluiContrefe()
    {
        $connection = Registry::getEntityManager();
        $connection->beginTransaction();
        try {
            $contas = tk_get_env_var('CONTAS');
            $existe_Erro = false;
            for ($i = 1; $i < count($contas) && !$existe_Erro; $i++) {

                list ($cdcontrefe, $nmcontrefe, $dtinivalid,
                    $dtfinvalid, $idanalsint, $cdcontant,
                    $cdnivel, $idtipocont, $idutilcont) = preg_split("/[|]/", $contas[$i]);

                $str_sub = array("\n", "\r");
                $idutilcont = substr(str_replace($str_sub, "", $idutilcont), 0, 1);
                $ContasImportadas = Contrefe::findOneByCdcontrefeAndIdanalsintAndIdutilcont($cdcontrefe, $idanalsint, $idutilcont);
                if ($ContasImportadas) {
                    tk_message(tk_get_message_by_name('msg_pbi00227_contaJaImport', array($cdcontrefe . ' - ' . $nmcontrefe)), 'info', true, true);
                    $existe_Erro = true;
                } elseif (!$cdcontrefe) {
                    tk_message(tk_get_message_by_name('msg_pbi00227_cont_n', array($i + 1)), 'info', true, true);
                    $existe_Erro = true;
                } elseif (!$idanalsint) {
                    tk_message(tk_get_message_by_name('msg_pbi00227_idTipoConta', array($i + 1)), 'info', true, true);
                    $existe_Erro = true;
                } elseif (!$idutilcont) {
                    tk_message(tk_get_message_by_name('msg_pbi00227_util_n', array($i + 1)), 'info', true, true);
                    $existe_Erro = true;
                }
                else
                {
                    if ($dtfinvalid)
                        $dtfinvalid = self::formataData(substr($dtfinvalid, 0, 2).'/'.substr($dtfinvalid, 2, 2).'/'.substr($dtfinvalid, 4, 4));
                    else
                        $dtfinvalid = null;

                    if ($dtinivalid)
                        $dtinivalid = self::formataData(substr($dtinivalid, 0, 2).'/'.substr($dtinivalid, 2, 2).'/'.substr($dtinivalid, 4, 4));
                    else
                        $dtfinvalid = null;

                    $dtinclusao = self::formataData(now());
                    $dtultatu = self::formataData(now());
                    $contaReferencial = new Contrefe();
                    $contaReferencial->setCdcontrefe($cdcontrefe);
                    $contaReferencial->setNmcontrefe($nmcontrefe);
                    $contaReferencial->setDtinivalid($dtinivalid);
                    $contaReferencial->setDtfinvalid($dtfinvalid);
                    $contaReferencial->setIdanalsint($idanalsint);
                    $contaReferencial->setCdcontant($cdcontant);
                    $contaReferencial->setCdnivel($cdnivel);
                    $contaReferencial->setIdtipocont($idtipocont);
                    $contaReferencial->setIdutilcont($idutilcont);
                    $contaReferencial->setNrorg(\Geral\Util\Ambiente::getNrorg());
                    $contaReferencial->setDtinclusao($dtinclusao);
                    $contaReferencial->setDtultatu($dtultatu);
                    $contaReferencial->persist();
                }
            }
            $connection->flush();
            $connection->commit();
            if(!$existe_Erro)
                tk_message(tk_get_message_by_name('msg_pbi00227_importacaoRealizada'), 'sucess', true, true);
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    public static function formataData($data){
        if(strlen($data) == 19)
            $data = DateUtil::truncateString($data);
        $data = DateUtil::getDatadeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
}
